@@ -28,6 +28,7 @@
 #ifndef __DOS2UNIX_H
 #define __DOS2UNIX_H
 
+#ifdef __DOS2UNIX_C
 /* ASCII mode. No conversion. */
 
 static int D2UAsciiTable[256] =
@@ -76,7 +77,7 @@ static int D2U7BitTable[256] =
 
 
 /* CP437 -> ISO-8859-1 */
-/* Non-convertable characters are converted to a dot (\x2e) */
+/* Non-convertible characters are converted to a dot (\x2e) */
 
 static int D2UIso437Table[256] =
 {
@@ -99,7 +100,7 @@ static int D2UIso437Table[256] =
 };
 
 /* CP850 -> ISO-8859-1 */
-/* Non-convertable characters are converted to a dot (\x2e) */
+/* Non-convertible characters are converted to a dot (\x2e) */
 
 static int D2UIso850Table[256] =
 {
@@ -122,7 +123,7 @@ static int D2UIso850Table[256] =
 };
 
 /* CP860 -> ISO-8859-1 */
-/* Non-convertable characters are converted to a dot (\x2e) */
+/* Non-convertible characters are converted to a dot (\x2e) */
 
 static int D2UIso860Table[256] =
 {
@@ -145,7 +146,7 @@ static int D2UIso860Table[256] =
 };
 
 /* CP863 -> ISO-8859-1 */
-/* Non-convertable characters are converted to a dot (\x2e) */
+/* Non-convertible characters are converted to a dot (\x2e) */
 
 static int D2UIso863Table[256] =
 {
@@ -168,7 +169,7 @@ static int D2UIso863Table[256] =
 };
 
 /* CP865 -> ISO-8859-1 */
-/* Non-convertable characters are converted to a dot (\x2e) */
+/* Non-convertible characters are converted to a dot (\x2e) */
 
 static int D2UIso865Table[256] =
 {
@@ -191,7 +192,7 @@ static int D2UIso865Table[256] =
 };
 
 /* CP1252 -> ISO-8859-1 */
-/* Non-convertable characters are converted to a dot (\x2e) */
+/* Non-convertible characters are converted to a dot (\x2e) */
 
 static int D2UIso1252Table[256] =
 {
@@ -212,5 +213,12 @@ static int D2UIso1252Table[256] =
   '\xe0', '\xe1', '\xe2', '\xe3', '\xe4', '\xe5', '\xe6', '\xe7', '\xe8', '\xe9', '\xea', '\xeb', '\xec', '\xed', '\xee', '\xef',
   '\xf0', '\xf1', '\xf2', '\xf3', '\xf4', '\xf5', '\xf6', '\xf7', '\xf8', '\xf9', '\xfa', '\xfb', '\xfc', '\xfd', '\xfe', '\xff',
 };
+#endif
+
+
+#ifdef D2U_UNICODE
+int ConvertDosToUnixW(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progname);
+#endif
+int ConvertDosToUnix(FILE* ipInF, FILE* ipOutF, CFlag *ipFlag, const char *progname);
 
 #endif
